@@ -69,11 +69,12 @@ class LabelledWeatherForecast(WeatherForecast):
 
 
 class TrainSampleLog:
+    COMPACTION_PERIOD_DAYS = 10
 
     def __init__(self, dirname: str):
         self.lock = RLock()
         self.__dirname = dirname
-        self.__last_compaction_time = datetime.now() - timedelta(days=30)
+        self.__last_compaction_time = datetime.now() - timedelta(days=self.COMPACTION_PERIOD_DAYS*2)
 
     def filename(self, compressed: bool = False):
         if compressed:
@@ -100,7 +101,7 @@ class TrainSampleLog:
                 line = sample.to_csv() + "\n"
                 file.write(line.encode(encoding='UTF-8'))
 
-        if datetime.now() > (self.__last_compaction_time + timedelta(days=10)):
+        if datetime.now() > (self.__last_compaction_time + timedelta(days=self.COMPACTION_PERIOD_DAYS)):
             self.__last_compaction_time = datetime.now()
             Thread(target=self.compact, args=(15,), daemon=True).start()
 
@@ -152,8 +153,14 @@ class TrainSampleLog:
                 file.write((LabelledWeatherForecast.csv_header() + "\n").encode(encoding='UTF-8'))
                 num_samples = len(samples)
                 num_survived = 0
+                previous_sample = None
                 for sample in samples:
-                    if sample.time.astimezone(pytz.UTC) > min_datetime.astimezone(pytz.UTC):
+                    expired = sample.time.astimezone(pytz.UTC) < min_datetime.astimezone(pytz.UTC)
+                    duplicate = False
+                    if previous_sample is not None:
+                        duplicate = previous_sample.time.astimezone(pytz.UTC) == sample.time.astimezone(pytz.UTC)
+                    previous_sample = sample
+                    if not expired and not duplicate:
                         num_survived += 1
                         line = sample.to_csv() + "\n"
                         file.write(line.encode(encoding='UTF-8'))
